summaryrefslogtreecommitdiffstats
path: root/lib/kpilotdevicelink.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kpilotdevicelink.h')
-rw-r--r--lib/kpilotdevicelink.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/kpilotdevicelink.h b/lib/kpilotdevicelink.h
index c4fb9f3..6fe02ef 100644
--- a/lib/kpilotdevicelink.h
+++ b/lib/kpilotdevicelink.h
@@ -42,7 +42,7 @@ class DeviceCommThread; ///< Thread for doing all palm device communications
* it waits for the actual device to become available, and
* then becomes ready to handle syncing.
*/
-enum LinktqStatus {
+enum LinkStatus {
Init,
WaitingForDevice,
FoundDevice,
@@ -100,15 +100,15 @@ public:
/**
* Get the status (state enum) of this link.
* @return The LinktqStatus enum for the link's current state.
*/
- LinktqStatus status() const
+ LinkStatus status() const
{
- return fLinktqStatus;
+ return fLinkStatus;
}
/** Get a human-readable string for the given status @p l. */
- static TQString statusString(LinktqStatus l);
+ static TQString statusString(LinkStatus l);
// The following API is the actual implementation of
// the KPilotLink API, for documentation see that file.
@@ -141,7 +141,7 @@ protected:
private:
- LinktqStatus fLinktqStatus;
+ LinkStatus fLinkStatus;
public:
@@ -100,15 +100,15 @@ public:
/**
* Get the status (state enum) of this link.
- * @return The LinktqStatus enum for the link's current state.
+ * @return The LinkStatus enum for the link's current state.
*/